import * as Formatter from "@himenon/openapi-parameter-formatter";
export const generateQueryString = (queryParameters) => {
    if (!queryParameters) {
        return undefined;
    }
    const queries = Object.entries(queryParameters).reduce((queryStringList, [key, item]) => {
        if (!item.value) {
            return queryStringList;
        }
        if (!item.style) {
            return queryStringList.concat(`${key}=${item.value}`);
        }
        const result = Formatter.QueryParameter.generate(key, item);
        if (result) {
            return queryStringList.concat(result);
        }
        return queryStringList;
    }, []);
    return queries.join("&");
};
export const create = (accessToken) => {
    const apiClientImpl = {
        request: async (httpMethod, url, headers, requestBody, queryParameters) => {
            const query = generateQueryString(queryParameters);
            const requestUrl = query ? url + "?" + encodeURI(query) : url;
            const requestHeaders = {
                ...headers,
                Authorization: "token " + accessToken,
            };
            const response = await fetch(requestUrl, {
                body: JSON.stringify(requestBody),
                headers: requestHeaders,
                method: httpMethod,
            });
            return await response.json();
        },
    };
    return apiClientImpl;
};
